Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Status ¶
type Status int
Status represents the known status of the connection
const ( // StatusUnknown means we couldn't determine if the connection is open because // of an unexpected error or an unsupported type of connection. // Clients should assume the connection is *open*. StatusUnknown Status = iota // StatusOpen means the connection is open. StatusOpen // StatusNotOpen means the connection is closed or broken. StatusNotOpen )
func Do ¶
Do checks if the connection is open. This is the primary function of the library. It communicates with the network stack but doesn't cause outbound traffic. The call completes in microseconds on Unix and up to 1.5 milliseconds on Windows. It doesn't interfere with other goroutines using the same connection. Supports TCP, TLS, and UDP connections.
Click to show internal directories.
Click to hide internal directories.